@@ -34,9 +34,9 @@ class BaseAction():
 			loglevel = logging.DEBUG
 		elif self._args.verbose == 3:
 			loglevel = logging.TRACE
-		elif self._args.verbose == 4:
+		else:
 			loglevel = logging.SINGLESTEP
-		logging.basicConfig(format = " {name:>20s} [{levelname:.1s}]: {message}", style = "{", level = loglevel)
+		logging.basicConfig(format = "{name:>30s} [{levelname:.1s}]: {message}", style = "{", level = loglevel)
 		self.run()
 
 	def run(self):
